@@ -23,6 +23,7 @@ from alastria_service_client.validators import (
     Address,
 )
 from alastria_identity.types import JwtToken, AlastriaToken
+from network_service_client.client import AClient as ANetworkClient, CLient as NetworkClient, Network as NetworkDTO, NetworksNames
 
 
 class AlastriaAuthService(AAlastriaAuthService):
@@ -33,7 +34,8 @@ class AlastriaAuthService(AAlastriaAuthService):
     @staticmethod
     def get_did(address: str) -> str:
         alastria_service_client: AClient = Client(service_host=settings.ALASTRIA_SERVICE_HOST)
-
+        network_data: NetworkDTO = NetworkClient(service_host=settings.NETWORK_SERVICE_HOST).get_network_by_name(NetworksNames.AlastriaDefaultName)
+        print(network_data)
         network_body = NetworkValidator(
             provider=settings.ALASTRIA_NODE_PATH,
             identity_manager_contract_address=settings.ALASTRIA_IDENTITY_MANAGER_CONTRACT_ADDRESS,  # TODO HOW MAKE THIS DATA DRIVEN ?
